# Create normalized splits for a dataset
# By Cristian R Munteanu, muntisa at gmail.com, University of A Coruna

library(MASS)

# read RAW data
data <- read.csv("ds2.corr.Tr.csv",header=T)

# normalize data
maxs <- apply(data, 2, max) 
mins <- apply(data, 2, min)
scaled <- as.data.frame(scale(data, center = mins, scale = maxs - mins))

# write NORMALIZED dataset
write.table(scaled, file = "ds2.corr.Tr.norm.csv", append = FALSE, quote = FALSE, sep = ",",
            eol = "\n", na = "NA", dec = ".", row.names = FALSE,
            col.names = TRUE, qmethod = c("escape", "double"))

# create splits with normalized data
for (iseed in 1:10){
  # set the seed = no of cases!
  set.seed(iseed)
  
  # split 75-25%
  index <- sample(1:nrow(data),round(0.75*nrow(data)))
  train <- data[index,]
  test <- data[-index,]
  
  # write train and validation/test normalized datasets
  train_ <- scaled[index,]
  test_ <- scaled[-index,]
  write.table(train_, file = paste("ds2.corr.Tr.norm.tr.",iseed,".csv",sep=""), append = FALSE, quote = FALSE, sep = ",",
              eol = "\n", na = "NA", dec = ".", row.names = FALSE,
              col.names = TRUE, qmethod = c("escape", "double"))
  write.table(test_, file =  paste("ds2.corr.Tr.norm.ts.",iseed,".csv",sep=""), append = FALSE, quote = FALSE, sep = ",",
              eol = "\n", na = "NA", dec = ".", row.names = FALSE,
              col.names = TRUE, qmethod = c("escape", "double"))
}
